==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/clientscope/HotRodClientScopeEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.clientscope;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodClientScopeEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity, org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.ClientScopeModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.ClientScopeModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity, org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity.HotRodClientScopeEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-21.0.0-sources.jar: org/keycloak/models/map/storage/hotRod/clientscope/HotRodClientScopeEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.clientscope;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodClientScopeEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity, org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.models.ClientScopeModel.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity.class;
    }
    @Override
    public String getCacheName() {
        return org.keycloak.models.map.storage.ModelEntityUtil.getModelName(org.keycloak.models.ClientScopeModel.class);
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity, org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.clientscope.HotRodClientScopeEntity.HotRodClientScopeEntitySchema.INSTANCE;
    }
}
